
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
//function tfrspwvt
//TFRSPWVT Unit test for the function TFRSPWV.
//  <-- NO CHECK ERROR OUTPUT -->
//       F. Auger, Dec. 1995 - O. Lemoine, March 1996.

// We test each property of the corresponding TFR :

N=128;

// Covariance by translation in time
t1=55; t2=70; f=0.3;
sig1=amgauss(N,t1).*fmconst(N,f,t1);
sig2=amgauss(N,t2).*fmconst(N,f,t2);
tfr1=Ctfrspwv(sig1);
tfr2=Ctfrspwv(sig2);
[tr,tc]=size(tfr1);
nu=round(f*(tc-1)*2)+1;
tfr=tfr1-tfr2(:,vecmodulo((1:tc)-t1+t2,tc));
if ~assert_checkfalse(or(or(abs(tfr)>sqrt(%eps)))),
 disp('tfrspwv test 1 failed');
end


// Reality of the TFR
sig=noisecg(N);
tfr=Ctfrspwv(sig);
if ~assert_checkfalse(or(abs(imag(tfr))>sqrt(%eps))),
 disp('tfrspwv test 2 failed');
end


// Energy conservation
sig=noisecg(N);
tfr=Ctfrspwv(sig,1:N,N,[1]);
Es=norm(sig)^2;
Etfr=sum(mtlb_mean(tfr));
if ~assert_checkalmostequal(abs(Etfr),abs(Es),%eps,1e-4),
 disp('tfrspwv test 3 failed');
end


// time localization
t0=30; sig=((1:N)'==t0)+0;
tfr=Ctfrspwv(sig,1:N,N,[1]);
[ik,jk]=find(tfr~=0.0);
if ~assert_checkfalse(or(jk~=t0)|or(ik'-(1:N)')),
 disp('tfrspwv test 4 failed');
end;


// frequency localization
f0=10;
sig=fmconst(N+6,f0/N);
tfr=Ctfrspwv(sig,N/2+2,N,tftb_window(11,'rect'),tftb_window(N+1,'rect'));
if ~assert_checkfalse((find(tfr>1/N)~=2*f0+1)|(abs(mtlb_mean(tfr)-1.0)>3.0*%eps)),
 disp('tfrspwv test 5 failed');
end;


// A SPWVD with a Dirac time-smoothing window is a PWVD
sig=noisecg(N);
tfr1=Ctfrspwv(sig,1:N,N,1);
tfr2=tfrpwv(sig);
if ~assert_checkfalse(or(or(abs(tfr1-tfr2)>sqrt(%eps)))),
 disp('tfrspwv test 6 failed');
end;


N=127;

// Covariance by translation in time
t1=55; t2=70; f=0.3;
sig1=amgauss(N,t1).*fmconst(N,f,t1);
sig2=amgauss(N,t2).*fmconst(N,f,t2);
tfr1=Ctfrspwv(sig1);
tfr2=Ctfrspwv(sig2);
[tr,tc]=size(tfr1);
nu=round(f*(tc-1)*2)+1;
tfr=tfr1-tfr2(:,vecmodulo((1:tc)-t1+t2,tc));
if ~assert_checkfalse(or(or(abs(tfr)>sqrt(%eps)))),
 disp('tfrspwv test 7 failed');
end


// Reality of the TFR
sig=noisecg(N);
tfr=Ctfrspwv(sig);
if ~assert_checkfalse(or(abs(imag(tfr))>sqrt(%eps))),
 disp('tfrspwv test 8 failed');
end


// Energy conservation
sig=noisecg(N);
tfr=Ctfrspwv(sig,1:N,N,[1]);
Es=norm(sig)^2;
Etfr=sum(mtlb_mean(tfr));
if ~assert_checkalmostequal(abs(Etfr),abs(Es),%eps,1e-4),
 disp('tfrspwv test 9 failed');
end


// time localization
t0=30; sig=((1:N)'==t0)+0;
tfr=Ctfrspwv(sig,1:N,N,[1]);
[ik,jk]=find(tfr~=0.0);
if ~assert_checkfalse(or(jk~=t0)|or(ik'-(1:N)')),
 disp('tfrspwv test 10 failed');
end;


// frequency localization
f0=10;
sig=fmconst(N+6,f0/N);
tfr=Ctfrspwv(sig,round(N/2)+2,N,tftb_window(11,'rect'),tftb_window(N,'rect'));
if ~assert_checkfalse((find(tfr>1/N)~=2*f0+1)|(abs(mtlb_mean(tfr)-1.0)>sqrt(%eps))),
 disp('tfrspwv test 11 failed');
end;


// A SPWVD with a Dirac time-smoothing window is a PWVD
sig=noisecg(N);
tfr1=Ctfrspwv(sig,1:N,N,1);
tfr2=tfrpwv(sig);
if ~assert_checkfalse(or(or(abs(tfr1-tfr2)>sqrt(%eps)))),
 disp('tfrspwv test 12 failed');
end;
